@@ -50,10 +50,14 @@ class GreedyTreeClassifier(DecisionTreeClassifier):
         self.complexity_ = compute_tree_complexity(self.tree_)
 
     def __str__(self):
+        s = '> ------------------------------\n'
+        s += '> Greedy CART Tree:\n'
+        s += '> \tPrediction is made by looking at the value in the appropriate leaf of the tree\n'
+        s += '> ------------------------------' + '\n'
         if self.feature_names is not None:
-            return 'GreedyTree:\n' + export_text(self, feature_names=self.feature_names, show_weights=True)
+            return s + export_text(self, feature_names=self.feature_names, show_weights=True)
         else:
-            return 'GreedyTree:\n' + export_text(self, show_weights=True)
+            return s + export_text(self, show_weights=True)
 
 
 class GreedyTreeRegressor(DecisionTreeRegressor):
